@@ -6,7 +6,7 @@ import Ptr
 import CString
 import CTypes
 import Foreign.Marshal.Alloc (mallocBytes, free)
-import GHC.IO (hGetBuf, hPutBuf)
+import System.IO (hGetBuf, hPutBuf)
 		   
 rawGetBytes :: Handle -> Int -> IO String
 rawGetBytes h n =
